import java.util.*;
import javax.servlet.http.*;

public class DatePulldown
{
	protected StringBuffer Buffer = new StringBuffer();
	protected Calendar Cal = new GregorianCalendar();

	protected String Name;

	//--------------------------------------------------------------------------
	public DatePulldown()
	{
		Name = "";
	}
	//--------------------------------------------------------------------------
	public DatePulldown(String name)
	{
		Name = new String(name);
	}
	//--------------------------------------------------------------------------
	public void setMonth(int month)
	{
		Cal.set(Calendar.MONTH, month - 1);
	}
	//--------------------------------------------------------------------------
	public void setDay(int day)
	{
		Cal.set(Calendar.DAY_OF_MONTH, day);
	}
	//--------------------------------------------------------------------------
	public void setYear(int year)
	{
		Cal.set(Calendar.YEAR, year);
	}
	//--------------------------------------------------------------------------
	public void setDate(Date date)
	{
		Cal.setTime(date);		
	}
	//--------------------------------------------------------------------------
	int StrToInt(String str)
	{
		int value;

		// Convert the string to an integer value. If there are conversion
		// problems, default to zero.

		try
		{
			Integer i = new Integer(str);
			value = i.intValue();
		}
		catch(NumberFormatException e)
		{
			value = 0;
		}

		return value;
	}
	//--------------------------------------------------------------------------
	public void setDate(HttpServletRequest request)
	{
		// We're pulling 3 fields out here:
		int month	= 0;
		int day		= 0;
		int year	= 0;

		// If this pulldown has been assigned a name, expect that the name will 
		// be prepended to the form variable names. Otherwise just use the 
		// variable names directly.

		if(Name != null && Name.length() > 0)
		{
			month	= StrToInt(request.getParameter(Name + ".month"));
			day		= StrToInt(request.getParameter(Name + ".day"));
			year	= StrToInt(request.getParameter(Name + ".year"));
		}
		else
		{
			month	= StrToInt(request.getParameter("month"));
			day		= StrToInt(request.getParameter("day"));
			year	= StrToInt(request.getParameter("year"));
		}
	
		Cal.set(year, month - 1, day); // Remember that the month needs to be zero-based.
	}
	//--------------------------------------------------------------------------
	public String toString()
	{
		Render();
		return Buffer.toString();
	}
	//--------------------------------------------------------------------------
	protected void Render()
	{
		Buffer.append(CreateMonthList(Cal.get(Calendar.MONTH)));
		Buffer.append(CreateDayList(Cal.get(Calendar.DAY_OF_MONTH))); // Make day value zero-based.
		Buffer.append(CreateYearList(Cal.get(Calendar.YEAR)));
	}
	//--------------------------------------------------------------------------
	protected String CreateMonthList(int givenMonth)
	{
		// Create a pulldown of months.
		// Select the given month from the list.

		StringBuffer monthList = new StringBuffer();

		monthList.append("<SELECT NAME=\"");

		// If a pulldown name has been spec'd, use it.
		if(Name != null && Name.length() > 0)
		{
			monthList.append(Name + ".");
		}

		monthList.append("month\">\n");

		for(int i = Calendar.JANUARY; i <= Calendar.DECEMBER; i++)
		{
			monthList.append("<OPTION");

			if(givenMonth == i)
			{
				// If a month was specified, select it in the list.
				monthList.append(" SELECTED");
			}

			monthList.append(">");
			monthList.append(i + 1); // Shift to 1-based counting.
			monthList.append("</OPTION>\n");
		}

		monthList.append("</SELECT>\n");

		return monthList.toString();
	}
	//--------------------------------------------------------------------------
	protected String CreateDayList(int givenDay)
	{
		// Create a pulldown of days of the month.
		// Select the given day from the list.

		StringBuffer dayList = new StringBuffer();

		dayList.append("<SELECT NAME=\"");

		// If a pulldown name has been spec'd, use it.
		if(Name != null && Name.length() > 0)
		{
			dayList.append(Name + ".");
		}

		dayList.append("day\">\n");


		// Note that some months have fewer than 31 days, but because
		// the pulldowns are dynamic, there is no way to customize that here.
		// We'll sanity-check the user's input later.
		for(int i = 1; i < 32; i++)
		{
			dayList.append("<OPTION");

			if(givenDay == i)
			{
				// If a day was specified, select it in the list.
				dayList.append(" SELECTED");
			}

			dayList.append(">");
			dayList.append(i);
			dayList.append("</OPTION>\n");
		}

		dayList.append("</SELECT>\n");

		return dayList.toString();
	}
	//--------------------------------------------------------------------------
	protected String CreateYearList(int givenYear)
	{
		// Create a pulldown of years.
		// The years pulldown should go back 99 years.
		// If a year is given, select it.

		StringBuffer yearList = new StringBuffer();

		yearList.append("<SELECT NAME=\"year\">\n");

		Calendar now = new GregorianCalendar();

		int endYear		= now.get(Calendar.YEAR);
		int startYear	= (endYear - 99);


		for(int i = startYear; i <= endYear; i++)
		{
			yearList.append("<OPTION");

			if(givenYear == i)
			{
				// If a day was specified, select it in the list.
				yearList.append(" SELECTED");
			}

			yearList.append(">");
			yearList.append(i);
			yearList.append("</OPTION>\n");
		}

		yearList.append("</SELECT>\n");

		return yearList.toString();
	}
	//--------------------------------------------------------------------------
}
